@@ -11,7 +11,7 @@ function octavia_install {
             if [[ ${DISTRO} =~ "rhel7" ]]; then
                 # Installing qemu would bring in the default OS qemu package,
                 # which is too old for Pike and later releases
-                # See https://review.openstack.org/#/c/438325 for details
+                # See https://review.opendev.org/#/c/438325 for details
                 install_package qemu-kvm
             else
                 install_package qemu
@@ -38,6 +38,16 @@ function octavia_lib_install {
     fi
 }
 
+function install_diskimage_builder {
+    if use_library_from_git "diskimage-builder"; then
+        GITREPO["diskimage-builder"]=$DISKIMAGE_BUILDER_REPO_URL
+        GITDIR["diskimage-builder"]=$DISKIMAGE_BUILDER_DIR
+        GITBRANCH["diskimage-builder"]=$DISKIMAGE_BUILDER_REPO_REF
+        git_clone_by_name "diskimage-builder"
+        setup_dev_lib -bindep "diskimage-builder"
+    fi
+}
+
 function set_octavia_worker_image_owner_id {
     image_id=$(openstack image list --property name=${OCTAVIA_AMP_IMAGE_NAME} -f value -c ID)
     owner_id=$(openstack image show ${image_id} -c owner -f value)
@@ -45,6 +55,9 @@ function set_octavia_worker_image_owner_id {
 }
 
 function build_octavia_worker_image {
+    # set up diskimage-builder if we need to
+    install_diskimage_builder
+
     # Pull in DIB local elements if they are defined in devstack
     if [ -n "$DIB_LOCAL_ELEMENTS" ]; then
         export DIB_LOCAL_ELEMENTS=$DIB_LOCAL_ELEMENTS
@@ -76,6 +89,21 @@ function build_octavia_worker_image {
     export PARAM_OCTAVIA_AMP_IMAGE_SIZE='-s '$OCTAVIA_AMP_IMAGE_SIZE
     fi
 
+    # Use the infra pypi mirror if it is available
+    if [[ -e /etc/ci/mirror_info.sh ]]; then
+        source /etc/ci/mirror_info.sh
+    fi
+    if [[ ${NODEPOOL_PYPI_MIRROR:+1} ]]; then
+        if [[ ${DIB_LOCAL_ELEMENTS:+1} ]]; then
+            export DIB_LOCAL_ELEMENTS="${DIB_LOCAL_ELEMENTS} pypi"
+        else
+            export DIB_LOCAL_ELEMENTS='pypi'
+        fi
+        export DIB_PYPI_MIRROR_URL=$NODEPOOL_PYPI_MIRROR
+        export DIB_PYPI_MIRROR_URL_1=$NODEPOOL_WHEEL_MIRROR
+        export DIB_PIP_RETRIES=0
+    fi
+
     if ! [ -f $OCTAVIA_AMP_IMAGE_FILE ]; then
         local dib_logs=/var/log/dib-build
         if [[ -e ${dib_logs} ]]; then
@@ -172,10 +200,9 @@ function _stop_octavia_apache_wsgi {
 function create_octavia_accounts {
     create_service_user $OCTAVIA
 
-    # Increase the octavia account secgroups quota
+    # Increase the service account secgroups quota
     # This is imporant for concurrent tempest testing
-    openstack quota set --secgroups 100 $OCTAVIA_PROJECT_NAME
-    openstack quota set --secgroup-rules 1000 $OCTAVIA_PROJECT_NAME
+    openstack quota set --secgroups 100 $SERVICE_PROJECT_NAME
 
     local octavia_service=$(get_or_create_service "octavia" \
         $OCTAVIA_SERVICE_TYPE "Octavia Load Balancing Service")
@@ -183,14 +210,20 @@ function create_octavia_accounts {
     if [[ "$WSGI_MODE" == "uwsgi" ]] && [[ "$OCTAVIA_NODE" == "main" ]] ; then
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE"
     elif [[ "$WSGI_MODE" == "uwsgi" ]]; then
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE"
     else
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/"
     fi
 }
@@ -238,6 +271,7 @@ function octavia_configure {
     # Setting other required default options
     iniset $OCTAVIA_CONF controller_worker amphora_driver ${OCTAVIA_AMPHORA_DRIVER}
     iniset $OCTAVIA_CONF controller_worker compute_driver ${OCTAVIA_COMPUTE_DRIVER}
+    iniset $OCTAVIA_CONF controller_worker volume_driver  ${OCTAVIA_VOLUME_DRIVER}
     iniset $OCTAVIA_CONF controller_worker network_driver ${OCTAVIA_NETWORK_DRIVER}
     iniset $OCTAVIA_CONF controller_worker amp_image_tag ${OCTAVIA_AMP_IMAGE_TAG}
 
@@ -252,15 +286,6 @@ function octavia_configure {
     iniset $OCTAVIA_CONF oslo_messaging rpc_thread_pool_size 2
     iniset $OCTAVIA_CONF oslo_messaging topic octavia_prov
 
-    # TODO(nmagnezi): Remove this when neutron-lbaas gets deprecated
-    # Setting neutron request_poll_timeout
-    iniset $NEUTRON_CONF octavia request_poll_timeout 3000
-    if [[ "$WSGI_MODE" == "uwsgi" ]]; then
-        iniadd $NEUTRON_CONF octavia base_url "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE"
-    else
-        iniadd $NEUTRON_CONF octavia base_url "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/"
-    fi
-
     # Uncomment other default options
     iniuncomment $OCTAVIA_CONF haproxy_amphora base_path
     iniuncomment $OCTAVIA_CONF haproxy_amphora base_cert_dir
@@ -311,14 +336,26 @@ function octavia_configure {
     if [[ "$(trueorfalse False OCTAVIA_USE_PREGENERATED_CERTS)" == "True" ]]; then
         cp -rfp ${OCTAVIA_PREGENERATED_CERTS_DIR} ${OCTAVIA_CERTS_DIR}
     else
-        source $OCTAVIA_DIR/bin/create_certificates.sh $OCTAVIA_CERTS_DIR $OCTAVIA_DIR/etc/certificates/openssl.cnf
+        pushd $OCTAVIA_DIR/bin
+        source create_dual_intermediate_CA.sh
+        mkdir -p ${OCTAVIA_CERTS_DIR}/private
+        chmod 700 ${OCTAVIA_CERTS_DIR}/private
+        cp -p etc/octavia/certs/server_ca.cert.pem ${OCTAVIA_CERTS_DIR}/
+        cp -p etc/octavia/certs/server_ca-chain.cert.pem ${OCTAVIA_CERTS_DIR}/
+        cp -p etc/octavia/certs/server_ca.key.pem ${OCTAVIA_CERTS_DIR}/private/
+        cp -p etc/octavia/certs/client_ca.cert.pem ${OCTAVIA_CERTS_DIR}/
+        cp -p etc/octavia/certs/client.cert-and-key.pem ${OCTAVIA_CERTS_DIR}/private/
+        popd
     fi
 
-    iniset $OCTAVIA_CONF haproxy_amphora client_cert ${OCTAVIA_CERTS_DIR}/client.pem
-    iniset $OCTAVIA_CONF haproxy_amphora server_ca ${OCTAVIA_CERTS_DIR}/ca_01.pem
-    iniset $OCTAVIA_CONF certificates ca_certificate ${OCTAVIA_CERTS_DIR}/ca_01.pem
-    iniset $OCTAVIA_CONF certificates ca_private_key ${OCTAVIA_CERTS_DIR}/private/cakey.pem
-    iniset $OCTAVIA_CONF certificates ca_private_key_passphrase foobar
+    iniset $OCTAVIA_CONF certificates ca_certificate ${OCTAVIA_CERTS_DIR}/server_ca.cert.pem
+    iniset $OCTAVIA_CONF certificates ca_private_key ${OCTAVIA_CERTS_DIR}/private/server_ca.key.pem
+    iniset $OCTAVIA_CONF certificates ca_private_key_passphrase not-secure-passphrase
+    iniset $OCTAVIA_CONF controller_worker client_ca ${OCTAVIA_CERTS_DIR}/client_ca.cert.pem
+    iniset $OCTAVIA_CONF haproxy_amphora client_cert ${OCTAVIA_CERTS_DIR}/private/client.cert-and-key.pem
+    iniset $OCTAVIA_CONF haproxy_amphora server_ca ${OCTAVIA_CERTS_DIR}/server_ca-chain.cert.pem
+
+    # Controller side symmetric encryption, not used for PKI
     iniset $OCTAVIA_CONF certificates server_certs_key_passphrase insecure-key-do-not-use-this-key
 
     if [[ "$OCTAVIA_USE_LEGACY_RBAC" == "True" ]]; then
@@ -364,8 +401,7 @@ function create_mgmt_network_interface {
     MGMT_PORT_ID=$(openstack port create --security-group lb-health-mgr-sec-grp --device-owner Octavia:health-mgr --host=$(hostname) -c id -f value --network lb-mgmt-net $PORT_FIXED_IP octavia-health-manager-$OCTAVIA_NODE-listen-port)
     MGMT_PORT_MAC=$(openstack port show -c mac_address -f value $MGMT_PORT_ID)
 
-    # TODO(johnsom) This gets the IPv4 address, should be updated for IPv6
-    MGMT_PORT_IP=$(openstack port show -f value -c fixed_ips $MGMT_PORT_ID | awk '{FS=",| "; gsub(",",""); gsub("'\''",""); for(i = 1; i <= NF; ++i) {if ($i ~ /^ip_address/) {n=index($i, "="); if (substr($i, n+1) ~ "\\.") print substr($i, n+1)}}}')
+    MGMT_PORT_IP=$(openstack port show -f yaml -c fixed_ips $MGMT_PORT_ID | awk '{FS=",|";gsub(",","");gsub("'\''","");for(line = 1; line <= NF; ++line) {if ($line ~ /^- ip_address:/) {split($line, word, " ");if (ENVIRON["IPV6_ENABLED"] == "" && word[3] ~ /\./) print word[3];if (ENVIRON["IPV6_ENABLED"] != "" && word[3] ~ /:/) print word[3];} else {split($line, word, " ");for(ind in word) {if (word[ind] ~ /^ip_address=/) {split(word[ind], token, "=");if (ENVIRON["IPV6_ENABLED"] == "" && token[2] ~ /\./) print token[2];if (ENVIRON["IPV6_ENABLED"] != "" && token[2] ~ /:/) print token[2];}}}}}')
     if function_exists octavia_create_network_interface_device ; then
         octavia_create_network_interface_device o-hm0 $MGMT_PORT_ID $MGMT_PORT_MAC
     elif [[ $NEUTRON_AGENT == "openvswitch" || $Q_AGENT == "openvswitch" ]]; then
@@ -382,7 +418,15 @@ function create_mgmt_network_interface {
         die "Unknown network controller. Please define octavia_create_network_interface_device"
     fi
     sudo ip link set dev o-hm0 address $MGMT_PORT_MAC
-    sudo iptables -I INPUT -i o-hm0 -p udp --dport 5555 -j ACCEPT
+    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_HM_LISTEN_PORT -j ACCEPT
+    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_ADMIN_PORT -j ACCEPT
+    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_TENANT_PORT -j ACCEPT
+    if [ $IPV6_ENABLED == 'true' ] ; then
+        sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_HM_LISTEN_PORT -j ACCEPT
+        sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_ADMIN_PORT -j ACCEPT
+        sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_TENANT_PORT -j ACCEPT
+    fi
+
 
     if [ $OCTAVIA_CONTROLLER_IP_PORT_LIST == 'auto' ] ; then
         iniset $OCTAVIA_CONF health_manager controller_ip_port_list $MGMT_PORT_IP:$OCTAVIA_HM_LISTEN_PORT
@@ -393,6 +437,13 @@ function create_mgmt_network_interface {
     iniset $OCTAVIA_CONF health_manager bind_ip $MGMT_PORT_IP
     iniset $OCTAVIA_CONF health_manager bind_port $OCTAVIA_HM_LISTEN_PORT
 
+    iniset $OCTAVIA_CONF amphora_agent admin_log_targets "${MGMT_PORT_IP}:${OCTAVIA_AMP_LOG_ADMIN_PORT}"
+    iniset $OCTAVIA_CONF amphora_agent tenant_log_targets "${MGMT_PORT_IP}:${OCTAVIA_AMP_LOG_TENANT_PORT}"
+    # Setting these here as the devstack rsyslog configuration expects
+    # these values.
+    iniset $OCTAVIA_CONF amphora_agent user_log_facility 0
+    iniset $OCTAVIA_CONF amphora_agent administrative_log_facility 1
+
 }
 
 function build_mgmt_network {
@@ -414,8 +465,13 @@ function build_mgmt_network {
     # Create security group and rules
     openstack security group create lb-health-mgr-sec-grp
     openstack security group rule create --protocol udp --dst-port $OCTAVIA_HM_LISTEN_PORT lb-health-mgr-sec-grp
+    openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_ADMIN_PORT lb-health-mgr-sec-grp
+    openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_TENANT_PORT lb-health-mgr-sec-grp
+
     if [ $IPV6_ENABLED == 'true' ] ; then
         openstack security group rule create --protocol udp --dst-port $OCTAVIA_HM_LISTEN_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
+        openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_ADMIN_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
+        openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_TENANT_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
     fi
 }
 
@@ -424,19 +480,9 @@ function configure_lb_mgmt_sec_grp {
     iniset ${OCTAVIA_CONF} controller_worker amp_secgroup_list ${OCTAVIA_MGMT_SEC_GRP_ID}
 }
 
-function configure_octavia_tempest {
-    # Load the amp_boot_network_list to tempest.conf and copy to tree
-
-    # TODO (ptoohill): remove check when tempest structure merges
-    if ! [ $OCTAVIA_TEMPEST == 'disabled' ] ; then
-        iniset $TEMPEST_CONFIG controller_worker amp_boot_network_list [$1]
-        cp $TEMPEST_CONFIG $OCTAVIA_TEMPEST_DIR/etc
-    fi
-}
-
 function create_amphora_flavor {
     # Pass even if it exists to avoid race condition on multinode
-    openstack flavor create --id auto --ram 1024 --disk ${OCTAVIA_AMP_IMAGE_SIZE:-2} --vcpus 1 --private m1.amphora -f value -c id || true
+    openstack flavor create --id auto --ram 1024 --disk ${OCTAVIA_AMP_IMAGE_SIZE:-2} --vcpus 1 --private m1.amphora -f value -c id --property hw_rng:allowed=True || true
     amp_flavor_id=$(openstack flavor show m1.amphora -f value -c id)
     iniset $OCTAVIA_CONF controller_worker amp_flavor_id $amp_flavor_id
 }
@@ -460,6 +506,14 @@ function configure_octavia_api_haproxy {
 
 }
 
+function configure_rsyslog {
+    sudo cp ${OCTAVIA_DIR}/devstack/etc/rsyslog/10-octavia-log-offloading.conf /etc/rsyslog.d/
+    sudo sed -e "
+        s|%ADMIN_PORT%|${OCTAVIA_AMP_LOG_ADMIN_PORT}|g;
+        s|%TENANT_PORT%|${OCTAVIA_AMP_LOG_TENANT_PORT}|g;
+    " -i /etc/rsyslog.d/10-octavia-log-offloading.conf
+}
+
 function octavia_start {
 
     if  ! ps aux | grep -q [o]-hm0 && [ $OCTAVIA_NODE != 'api' ] ; then
@@ -480,6 +534,8 @@ function octavia_start {
     run_process $OCTAVIA_CONSUMER  "$OCTAVIA_CONSUMER_BINARY $OCTAVIA_CONSUMER_ARGS"
     run_process $OCTAVIA_HOUSEKEEPER  "$OCTAVIA_HOUSEKEEPER_BINARY $OCTAVIA_HOUSEKEEPER_ARGS"
     run_process $OCTAVIA_HEALTHMANAGER  "$OCTAVIA_HEALTHMANAGER_BINARY $OCTAVIA_HEALTHMANAGER_ARGS"
+
+    restart_service rsyslog
 }
 
 function octavia_stop {
@@ -540,6 +596,10 @@ function octavia_cleanup {
     fi
 
     sudo rm -rf $NOVA_STATE_PATH $NOVA_AUTH_CACHE_DIR
+
+    sudo rm -f /etc/rsyslog.d/10-octavia-log-offloading.conf
+    restart_service rsyslog
+
 }
 
 function add_load-balancer_roles {
@@ -584,7 +644,7 @@ function octavia_init {
        OCTAVIA_AMP_IMAGE_ID=$(openstack image list -f value --property name=${OCTAVIA_AMP_IMAGE_NAME} -c ID)
 
        if [ -n "$OCTAVIA_AMP_IMAGE_ID" ]; then
-           openstack image set --tag ${OCTAVIA_AMP_IMAGE_TAG} ${OCTAVIA_AMP_IMAGE_ID}
+           openstack image set --tag ${OCTAVIA_AMP_IMAGE_TAG} --property hw_architecture='x86_64' --property hw_rng_model=virtio ${OCTAVIA_AMP_IMAGE_ID}
        fi
 
        # Create a management network.
@@ -594,20 +654,12 @@ function octavia_init {
 
        create_octavia_accounts
 
-       # Adds service and endpoint
-       if is_service_enabled tempest; then
-           configure_octavia_tempest ${OCTAVIA_AMP_NETWORK_ID}
-       fi
-
        add_load-balancer_roles
+
+       configure_rsyslog
    elif [ $OCTAVIA_NODE == 'api' ] ; then
        create_octavia_accounts
 
-       # Adds service and endpoint
-       if is_service_enabled tempest; then
-           configure_octavia_tempest ${OCTAVIA_AMP_NETWORK_ID}
-       fi
-
        add_load-balancer_roles
    fi
 
