@@ -167,7 +167,7 @@ class AmphoraInfo(object):
                     if (item[0] == 'IFLA_IFNAME' and
                             not item[1].startswith('eth')):
                         break
-                    elif item[0] == 'IFLA_IFNAME':
+                    if item[0] == 'IFLA_IFNAME':
                         interface_name = item[1]
                     if item[0] == 'IFLA_STATS64':
                         networks[interface_name] = dict(
