@@ -444,7 +444,7 @@ class Loadbalancer(object):
 
     def _check_ssl_filename_format(self, filename):
         # check if the format is (xxx.)*xxx.pem
-        if not re.search('(\w.)+pem', filename):
+        if not re.search(r'(\w.)+pem', filename):
             raise exceptions.HTTPException(
                 response=webob.Response(json=dict(
                     message='Filename has wrong format'), status=400))
