@@ -35,8 +35,8 @@ V6_VS_REGEX = re.compile(r"virtual_server\s([\w*:]+\b)\s(\d{1,5})")
 V6_RS_REGEX = re.compile(r"real_server\s([\w*:]+\b)\s(\d{1,5})")
 CONFIG_COMMENT_REGEX = re.compile(
     r"#\sConfiguration\sfor\s(\w+)\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12})")
-DISABLED_CONFIG_COMMENT_REGEX = re.compile(
-    r"#\s(\w+)\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12}) is disabled")
+DISABLED_MEMBER_COMMENT_REGEX = re.compile(
+    r"#\sMember\s(\w{8}-\w{4}-\w{4}-\w{4}-\w{12}) is disabled")
 
 CHECKER_REGEX = re.compile(r"MISC_CHECK")
 
@@ -73,9 +73,9 @@ def get_listener_realserver_mapping(ns_name, listener_ip_port,
     ip_obj = ipaddress.ip_address(six.text_type(listener_ip.strip('[]')))
     output = read_kernel_file(ns_name, KERNEL_LVS_PATH).split('\n')
     if ip_obj.version == 4:
-        ip_to_hex_format = "%.8X" % ip_obj._ip
+        ip_to_hex_format = "0%X" % ip_obj._ip
     else:
-        ip_to_hex_format = '\[' + ip_obj.exploded + '\]'
+        ip_to_hex_format = r'\[' + ip_obj.exploded + r'\]'
     port_hex_format = "%.4X" % int(listener_port)
     idex = ip_to_hex_format + ':' + port_hex_format
 
@@ -152,14 +152,6 @@ def get_udp_listener_resource_ipports_nsname(listener_id):
             listener_ip_port = V6_VS_REGEX.findall(cfg)
         listener_ip_port = listener_ip_port[0] if listener_ip_port else []
 
-        disabled_resource_ids = DISABLED_CONFIG_COMMENT_REGEX.findall(cfg)
-
-        listener_disabled = any(True
-                                for resource in disabled_resource_ids
-                                if resource[0] == 'Listener')
-        if listener_disabled:
-            return None, ns_name
-
         if not listener_ip_port:
             # If not get listener_ip_port from the lvs config file,
             # that means the udp listener's default pool have no enabled member
@@ -189,11 +181,7 @@ def get_udp_listener_resource_ipports_nsname(listener_id):
             elif resource_type == 'Members':
                 resource_ipport_mapping[resource_type].append(value)
 
-        disabled_member_ids = [
-            resource[1]
-            for resource in disabled_resource_ids
-            if resource[0] == 'Member'
-        ]
+        disabled_member_ids = DISABLED_MEMBER_COMMENT_REGEX.findall(cfg)
 
         resource_type = 'Members'
         for member_id in disabled_member_ids:
@@ -230,7 +218,7 @@ def get_udp_listener_pool_status(listener_id):
      ns_name) = get_udp_listener_resource_ipports_nsname(listener_id)
     if 'Pool' not in resource_ipport_mapping:
         return {}
-    elif 'Members' not in resource_ipport_mapping:
+    if 'Members' not in resource_ipport_mapping:
         return {'lvs': {
             'uuid': resource_ipport_mapping['Pool']['id'],
             'status': constants.DOWN,
@@ -346,11 +334,11 @@ def get_ipvsadm_info(ns_name, is_stats_cmd=False):
         vs_fields.remove('Flags')
     rs_fields = fields[index + 1:]
     for key in list(value_mapping.keys()):
-        value_mapping[key]['Listener'] = [
-            i for i in zip(vs_fields, value_mapping[key]['Listener'])]
+        value_mapping[key]['Listener'] = list(
+            zip(vs_fields, value_mapping[key]['Listener']))
         member_res = []
         for member_value in value_mapping[key]['Members']:
-            member_res.append([i for i in zip(rs_fields, member_value)])
+            member_res.append(list(zip(rs_fields, member_value)))
         value_mapping[key]['Members'] = member_res
 
     return value_mapping
@@ -375,10 +363,6 @@ def get_udp_listeners_stats():
         (resource_ipport_mapping,
          ns_name) = get_udp_listener_resource_ipports_nsname(check_listener_id)
 
-        # Listener is disabled, we don't need to send an update
-        if resource_ipport_mapping is None:
-            continue
-
         # Since we found the keepalived running, acknowledge the listener
         # in the heartbeat. If this listener has a pool and members,
         # the stats will be updated later in the code flow.
