@@ -15,6 +15,7 @@
 import functools
 import hashlib
 import os
+import ssl
 import time
 import warnings
 
@@ -36,9 +37,6 @@ import octavia.common.jinja.haproxy.split_listeners.jinja_cfg as jinja_split
 from octavia.common.jinja.lvs import jinja_cfg as jinja_udp_cfg
 from octavia.common.tls_utils import cert_parser
 from octavia.common import utils
-from octavia.db import api as db_apis
-from octavia.db import repositories as repo
-
 
 LOG = logging.getLogger(__name__)
 API_VERSION = consts.API_VERSION
@@ -147,8 +145,6 @@ class HaproxyAmphoraLoadBalancerDriver(
                       'process mode.', amphora.id, loadbalancer.id)
 
         has_tcp = False
-        certs = {}
-        listeners_to_update = []
         for listener in loadbalancer.listeners:
             LOG.debug("%s updating listener %s on amphora %s",
                       self.__class__.__name__, listener.id, amphora.id)
@@ -166,67 +162,42 @@ class HaproxyAmphoraLoadBalancerDriver(
                 else:
                     obj_id = loadbalancer.id
 
-                try:
-                    certs.update({
-                        listener.tls_certificate_id:
-                        self._process_tls_certificates(
-                            listener, amphora, obj_id)['tls_cert']})
-                    certs.update({listener.client_ca_tls_certificate_id:
-                                  self._process_secret(
-                                      listener,
-                                      listener.client_ca_tls_certificate_id,
-                                      amphora, obj_id)})
-                    certs.update({listener.client_crl_container_id:
-                                  self._process_secret(
-                                      listener,
-                                      listener.client_crl_container_id,
-                                      amphora, obj_id)})
+                self._process_tls_certificates(listener, amphora, obj_id)
 
-                    certs.update(self._process_listener_pool_certs(
-                        listener, amphora, obj_id))
+                client_ca_filename = self._process_secret(
+                    listener, listener.client_ca_tls_certificate_id,
+                    amphora, obj_id)
+                crl_filename = self._process_secret(
+                    listener, listener.client_crl_container_id,
+                    amphora, obj_id)
+                pool_tls_certs = self._process_listener_pool_certs(
+                    listener, amphora, obj_id)
 
-                    if split_config:
-                        config = self.jinja_split.build_config(
-                            host_amphora=amphora, listener=listener,
-                            haproxy_versions=haproxy_versions,
-                            client_ca_filename=certs[
-                                listener.client_ca_tls_certificate_id],
-                            client_crl=certs[listener.client_crl_container_id],
-                            pool_tls_certs=certs)
-                        self.clients[amphora.api_version].upload_config(
-                            amphora, listener.id, config,
-                            timeout_dict=timeout_dict)
-                        self.clients[amphora.api_version].reload_listener(
-                            amphora, listener.id, timeout_dict=timeout_dict)
-                    else:
-                        listeners_to_update.append(listener)
-                except Exception as e:
-                    LOG.exception('Unable to update listener {0} due to '
-                                  '"{1}". Skipping this listener.'.format(
-                                      listener.id, e))
-                    listener_repo = repo.ListenerRepository()
-                    listener_repo.update(db_apis.get_session(), listener.id,
-                                         provisioning_status=consts.ERROR,
-                                         operating_status=consts.ERROR)
+                if split_config:
+                    config = self.jinja_split.build_config(
+                        host_amphora=amphora, listener=listener,
+                        haproxy_versions=haproxy_versions,
+                        client_ca_filename=client_ca_filename,
+                        client_crl=crl_filename,
+                        pool_tls_certs=pool_tls_certs)
+                    self.clients[amphora.api_version].upload_config(
+                        amphora, listener.id, config,
+                        timeout_dict=timeout_dict)
+                    self.clients[amphora.api_version].reload_listener(
+                        amphora, listener.id, timeout_dict=timeout_dict)
 
         if has_tcp and not split_config:
-            if listeners_to_update:
-                # Generate HaProxy configuration from listener object
-                config = self.jinja_combo.build_config(
-                    host_amphora=amphora, listeners=listeners_to_update,
-                    tls_certs=certs,
-                    haproxy_versions=haproxy_versions)
-                self.clients[amphora.api_version].upload_config(
-                    amphora, loadbalancer.id, config,
-                    timeout_dict=timeout_dict)
-                self.clients[amphora.api_version].reload_listener(
-                    amphora, loadbalancer.id, timeout_dict=timeout_dict)
-            else:
-                # If we aren't updating any listeners, make sure there are
-                # no listeners hanging around. For example if this update
-                # was called from a listener delete.
-                self.clients[amphora.api_version].delete_listener(
-                    amphora, loadbalancer.id)
+            # Generate HaProxy configuration from listener object
+            config = self.jinja_combo.build_config(
+                host_amphora=amphora, listeners=loadbalancer.listeners,
+                haproxy_versions=haproxy_versions,
+                client_ca_filename=client_ca_filename,
+                client_crl=crl_filename,
+                pool_tls_certs=pool_tls_certs)
+            self.clients[amphora.api_version].upload_config(
+                amphora, loadbalancer.id, config, timeout_dict=timeout_dict)
+            self.clients[amphora.api_version].reload_listener(
+                amphora, loadbalancer.id, timeout_dict=timeout_dict)
 
     def _udp_update(self, listener, vip):
         LOG.debug("Amphora %s keepalivedlvs, updating "
@@ -490,7 +461,8 @@ class HaproxyAmphoraLoadBalancerDriver(
                 amphora, obj_id, pem=secret, md5=md5, name=name)
         return name
 
-    def _process_listener_pool_certs(self, listener, amphora, obj_id):
+    def _process_listener_pool_certs(self, listener, amphora=None,
+                                     obj_id=None):
         #     {'POOL-ID': {
         #         'client_cert': client_full_filename,
         #         'ca_cert': ca_cert_full_filename,
@@ -508,34 +480,33 @@ class HaproxyAmphoraLoadBalancerDriver(
                                              amphora, obj_id))
         return pool_certs_dict
 
-    def _process_pool_certs(self, listener, pool, amphora, obj_id):
+    def _process_pool_certs(self, listener, pool, amphora=None, obj_id=None):
         pool_cert_dict = dict()
 
         # Handle the client cert(s) and key
         if pool.tls_certificate_id:
             data = cert_parser.load_certificates_data(self.cert_manager, pool)
-            tls_cert = data['tls_cert']
-            pem = cert_parser.build_pem(tls_cert)
+            pem = cert_parser.build_pem(data)
             try:
                 pem = pem.encode('utf-8')
             except AttributeError:
                 pass
             md5 = hashlib.md5(pem).hexdigest()  # nosec
-            name = '{id}.pem'.format(id=tls_cert.id)
+            name = '{id}.pem'.format(id=data.id)
             if amphora and obj_id:
                 self._upload_cert(amphora, obj_id, pem=pem, md5=md5, name=name)
             pool_cert_dict['client_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
         if pool.ca_tls_certificate_id:
             name = self._process_secret(listener, pool.ca_tls_certificate_id,
                                         amphora, obj_id)
             pool_cert_dict['ca_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
         if pool.crl_container_id:
             name = self._process_secret(listener, pool.crl_container_id,
                                         amphora, obj_id)
             pool_cert_dict['crl'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
 
         return pool_cert_dict
 
@@ -584,6 +555,12 @@ class CustomHostNameCheckingAdapter(requests.adapters.HTTPAdapter):
         return super(CustomHostNameCheckingAdapter,
                      self).cert_verify(conn, url, verify, cert)
 
+    def init_poolmanager(self, *pool_args, **pool_kwargs):
+        proto = CONF.amphora_agent.agent_tls_protocol.replace('.', '_')
+        pool_kwargs['ssl_version'] = getattr(ssl, "PROTOCOL_%s" % proto)
+        return super(CustomHostNameCheckingAdapter,
+                     self).init_poolmanager(*pool_args, **pool_kwargs)
+
 
 class AmphoraAPIClientBase(object):
     def __init__(self):
