@@ -106,12 +106,12 @@ class NoopManager(object):
         self.amphoraconfig[amphora.id, pem_file] = (amphora.id, pem_file,
                                                     'update_amp_cert_file')
 
-    def update_agent_config(self, amphora, agent_config):
+    def update_amphora_agent_config(self, amphora, agent_config):
         LOG.debug("Amphora %s no-op, update agent config amphora "
                   "%s, with agent config %s",
                   self.__class__.__name__, amphora.id, agent_config)
         self.amphoraconfig[amphora.id, agent_config] = (
-            amphora.id, agent_config, 'update_agent_config')
+            amphora.id, agent_config, 'update_amphora_agent_config')
 
 
 class NoopAmphoraLoadBalancerDriver(
@@ -163,8 +163,8 @@ class NoopAmphoraLoadBalancerDriver(
 
         self.driver.upload_cert_amp(amphora, pem_file)
 
-    def update_agent_config(self, amphora, agent_config):
-        self.driver.update_agent_config(amphora, agent_config)
+    def update_amphora_agent_config(self, amphora, agent_config):
+        self.driver.update_amphora_agent_config(amphora, agent_config)
 
     def update_vrrp_conf(self, loadbalancer):
         pass
