@@ -14,6 +14,7 @@
 
 import copy
 
+import netaddr
 import six
 from wsme import types as wtypes
 
@@ -43,6 +44,20 @@ class IPAddressType(wtypes.UserType):
                 raise ValueError(error)
 
 
+class CidrType(wtypes.UserType):
+    basetype = unicode
+    name = 'cidr'
+
+    @staticmethod
+    def validate(value):
+        """Validates whether value is an IPv4 or IPv6 CIDR."""
+        try:
+            return str(netaddr.IPNetwork(value).cidr)
+        except (ValueError, netaddr.core.AddrFormatError):
+            error = 'Value should be IPv4 or IPv6 CIDR format'
+            raise ValueError(error)
+
+
 class URLType(wtypes.UserType):
     basetype = unicode
     name = 'url'
@@ -75,7 +90,7 @@ class URLPathType(wtypes.UserType):
 
 
 class BaseMeta(wtypes.BaseMeta):
-    def __new__(mcs, name, bases, dct):
+    def __new__(cls, name, bases, dct):
         def get_tenant_id(self):
             tenant_id = getattr(self, '_tenant_id', wtypes.Unset)
             # If tenant_id was explicitly set to Unset, return that
@@ -101,7 +116,7 @@ class BaseMeta(wtypes.BaseMeta):
                 get_tenant_id, set_tenant_id)
             # This will let us know if tenant_id was explicitly set to Unset
             dct['_unset_tenant'] = False
-        return super(BaseMeta, mcs).__new__(mcs, name, bases, dct)
+        return super(BaseMeta, cls).__new__(cls, name, bases, dct)
 
 
 @six.add_metaclass(BaseMeta)
@@ -155,14 +170,6 @@ class BaseType(wtypes.Base):
             res[k] = v
         return res
 
-    @classmethod
-    def translate_key_to_data_model(cls, key):
-        """Translate the keys from wsme class type, to data_model."""
-        if not hasattr(cls, '_type_to_model_map') or (
-                key not in cls._type_to_model_map):
-            return key
-        return cls._type_to_model_map[key]
-
     def to_dict(self, render_unsets=False):
         """Converts Octavia WSME type to dictionary.
 
