@@ -184,7 +184,7 @@ class HealthMonitorController(base.BaseController):
                         udp_connect_min_interval_health_monitor)
             if conf_set < 0:
                 return
-            elif request.delay < conf_set:
+            if request.delay < conf_set:
                 raise exceptions.ValidationException(detail=_(
                     "The request delay value %(delay)s should be larger than "
                     "%(conf_set)s for %(type)s health monitor type.") % {
@@ -199,19 +199,16 @@ class HealthMonitorController(base.BaseController):
         context = pecan.request.context.get('octavia_context')
         health_monitor = health_monitor_.healthmonitor
 
-        pool = self._get_db_pool(context.session, health_monitor.pool_id)
-
-        health_monitor.project_id, provider = self._get_lb_project_id_provider(
-            context.session, pool.load_balancer_id)
-
-        self._auth_validate_action(context, health_monitor.project_id,
-                                   consts.RBAC_POST)
-
         if (not CONF.api_settings.allow_ping_health_monitors and
                 health_monitor.type == consts.HEALTH_MONITOR_PING):
             raise exceptions.DisabledOption(
                 option='type', value=consts.HEALTH_MONITOR_PING)
 
+        pool = self._get_db_pool(context.session, health_monitor.pool_id)
+
+        health_monitor.project_id, provider = self._get_lb_project_id_provider(
+            context.session, pool.load_balancer_id)
+
         if pool.protocol == consts.PROTOCOL_UDP:
             self._validate_healthmonitor_request_for_udp(health_monitor)
         else:
@@ -221,6 +218,9 @@ class HealthMonitorController(base.BaseController):
                     "%(protocol)s.") % {'type': health_monitor.type,
                                         'protocol': consts.PROTOCOL_UDP})
 
+        self._auth_validate_action(context, health_monitor.project_id,
+                                   consts.RBAC_POST)
+
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
 
