@@ -117,12 +117,10 @@ class LoadBalancersController(base.BaseController):
                 state=prov_status, id=id)
 
     @staticmethod
-    def _validate_network_and_fill_or_validate_subnet(load_balancer,
-                                                      context=None):
+    def _validate_network_and_fill_or_validate_subnet(load_balancer):
         network = validate.network_exists_optionally_contains_subnet(
             network_id=load_balancer.vip_network_id,
-            subnet_id=load_balancer.vip_subnet_id,
-            context=context)
+            subnet_id=load_balancer.vip_subnet_id)
         if not load_balancer.vip_subnet_id:
             network_driver = utils.get_network_driver()
             if load_balancer.vip_address:
@@ -170,10 +168,8 @@ class LoadBalancersController(base.BaseController):
                         break
 
     @staticmethod
-    def _validate_port_and_fill_or_validate_subnet(load_balancer,
-                                                   context=None):
-        port = validate.port_exists(port_id=load_balancer.vip_port_id,
-                                    context=context)
+    def _validate_port_and_fill_or_validate_subnet(load_balancer):
+        port = validate.port_exists(port_id=load_balancer.vip_port_id)
         validate.check_port_in_use(port)
         load_balancer.vip_network_id = port.network_id
 
@@ -188,8 +184,7 @@ class LoadBalancersController(base.BaseController):
 
         # Identify the subnet for this port
         if load_balancer.vip_subnet_id:
-            validate.subnet_exists(subnet_id=load_balancer.vip_subnet_id,
-                                   context=context)
+            validate.subnet_exists(subnet_id=load_balancer.vip_subnet_id)
         else:
             if load_balancer.vip_address:
                 for port_fixed_ip in port.fixed_ips:
@@ -207,7 +202,7 @@ class LoadBalancersController(base.BaseController):
                     "VIP port's subnet could not be determined. Please "
                     "specify either a VIP subnet or address."))
 
-    def _validate_vip_request_object(self, load_balancer, context=None):
+    def _validate_vip_request_object(self, load_balancer):
         allowed_network_objects = []
         if CONF.networking.allow_vip_port_id:
             allowed_network_objects.append('vip_port_id')
@@ -239,12 +234,10 @@ class LoadBalancersController(base.BaseController):
 
         # Validate the port id
         if load_balancer.vip_port_id:
-            self._validate_port_and_fill_or_validate_subnet(load_balancer,
-                                                            context=context)
+            self._validate_port_and_fill_or_validate_subnet(load_balancer)
         # If no port id, validate the network id (and subnet if provided)
         elif load_balancer.vip_network_id:
-            self._validate_network_and_fill_or_validate_subnet(load_balancer,
-                                                               context=context)
+            self._validate_network_and_fill_or_validate_subnet(load_balancer)
         # Validate just the subnet id
         elif load_balancer.vip_subnet_id:
             subnet = validate.subnet_exists(
@@ -354,7 +347,7 @@ class LoadBalancersController(base.BaseController):
         self._auth_validate_action(context, load_balancer.project_id,
                                    constants.RBAC_POST)
 
-        self._validate_vip_request_object(load_balancer, context=context)
+        self._validate_vip_request_object(load_balancer)
 
         self._validate_flavor(context.session, load_balancer)
 
@@ -595,8 +588,7 @@ class LoadBalancersController(base.BaseController):
 
             # Also prepare the baseline object data
             old_provider_lb = (
-                driver_utils.db_loadbalancer_to_provider_loadbalancer(
-                    db_lb, for_delete=True))
+                driver_utils.db_loadbalancer_to_provider_loadbalancer(db_lb))
 
             # Dispatch to the driver
             LOG.info("Sending update Load Balancer %s to provider "
@@ -671,11 +663,11 @@ class LoadBalancersController(base.BaseController):
         if is_children:
             controller = remainder[0]
             remainder = remainder[1:]
-            if controller == 'status' or controller == 'statuses':
+            if controller in ('status', 'statuses'):
                 return StatusController(lb_id=id), remainder
-            elif controller == 'stats':
+            if controller == 'stats':
                 return StatisticsController(lb_id=id), remainder
-            elif controller == 'failover':
+            if controller == 'failover':
                 return FailoverController(lb_id=id), remainder
         return None
 
