@@ -308,10 +308,12 @@ CREATED_AT = 'created_at'
 CRL_CONTAINER_ID = 'crl_container_id'
 DELTA = 'delta'
 DELTAS = 'deltas'
+DESCRIPTION = 'description'
 ENABLED = 'enabled'
 FAILED_AMPHORA = 'failed_amphora'
 FAILOVER_AMPHORA = 'failover_amphora'
 FAILOVER_AMPHORA_ID = 'failover_amphora_id'
+FIELDS = 'fields'
 FLAVOR_ID = 'flavor_id'
 HEALTH_MON = 'health_mon'
 HEALTH_MONITOR = 'health_monitor'
