@@ -16,14 +16,11 @@
 
 import re
 
-from oslo_log import log as logging
 import six
 from sqlalchemy.orm import collections
 
 from octavia.common import constants
 
-LOG = logging.getLogger(__name__)
-
 
 class BaseDataModel(object):
     def to_dict(self, calling_classes=None, recurse=False, **kwargs):
@@ -50,9 +47,15 @@ class BaseDataModel(object):
                                         calling_classes + [type(self)]),
                                         recurse=recurse))
                             else:
+                                # TODO(rm_work): Is the idea that if this list
+                                #  contains ANY BaseDataModel, that all of them
+                                #  are data models, and we may as well quit?
+                                #  Or, were we supposed to append a `None` for
+                                #  each one? I assume the former?
                                 ret[attr] = None
+                                break
                         else:
-                            ret[attr] = item
+                            ret[attr].append(item)
                 elif isinstance(getattr(self, attr), BaseDataModel):
                     if type(self) not in calling_classes:
                         ret[attr] = value.to_dict(
@@ -65,8 +68,10 @@ class BaseDataModel(object):
                 else:
                     ret[attr] = value
             else:
-                if isinstance(getattr(self, attr), (BaseDataModel, list)):
+                if isinstance(getattr(self, attr), BaseDataModel):
                     ret[attr] = None
+                elif isinstance(getattr(self, attr), list):
+                    ret[attr] = []
                 else:
                     ret[attr] = value
 
@@ -99,19 +104,20 @@ class BaseDataModel(object):
                                       'Listener', 'Amphora', 'L7Policy',
                                       'L7Rule']:
             return obj.__class__.__name__ + obj.id
-        elif obj.__class__.__name__ in ['SessionPersistence', 'HealthMonitor']:
+        if obj.__class__.__name__ in ['SessionPersistence', 'HealthMonitor']:
             return obj.__class__.__name__ + obj.pool_id
-        elif obj.__class__.__name__ in ['ListenerStatistics']:
+        if obj.__class__.__name__ in ['ListenerStatistics']:
             return obj.__class__.__name__ + obj.listener_id + obj.amphora_id
-        elif obj.__class__.__name__ in ['VRRPGroup', 'Vip']:
+        if obj.__class__.__name__ in ['ListenerCidr']:
+            return obj.__class__.__name__ + obj.listener_id + obj.cidr
+        if obj.__class__.__name__ in ['VRRPGroup', 'Vip']:
             return obj.__class__.__name__ + obj.load_balancer_id
-        elif obj.__class__.__name__ in ['AmphoraHealth']:
+        if obj.__class__.__name__ in ['AmphoraHealth']:
             return obj.__class__.__name__ + obj.amphora_id
-        elif obj.__class__.__name__ in ['SNI']:
+        if obj.__class__.__name__ in ['SNI']:
             return (obj.__class__.__name__ +
                     obj.listener_id + obj.tls_container_id)
-        else:
-            raise NotImplementedError
+        raise NotImplementedError
 
     def _find_in_graph(self, key, _visited_nodes=None):
         """Locates an object with the given unique key in the current
@@ -123,26 +129,25 @@ class BaseDataModel(object):
         if mykey in _visited_nodes:
             # Seen this node already, don't traverse further
             return None
-        elif mykey == key:
+        if mykey == key:
             return self
-        else:
-            _visited_nodes.append(mykey)
-            attr_names = [attr_name for attr_name in dir(self)
-                          if not attr_name.startswith('_')]
-            for attr_name in attr_names:
-                attr = getattr(self, attr_name)
-                if isinstance(attr, BaseDataModel):
-                    result = attr._find_in_graph(
-                        key, _visited_nodes=_visited_nodes)
-                    if result is not None:
-                        return result
-                elif isinstance(attr, (collections.InstrumentedList, list)):
-                    for item in attr:
-                        if isinstance(item, BaseDataModel):
-                            result = item._find_in_graph(
-                                key, _visited_nodes=_visited_nodes)
-                            if result is not None:
-                                return result
+        _visited_nodes.append(mykey)
+        attr_names = [attr_name for attr_name in dir(self)
+                      if not attr_name.startswith('_')]
+        for attr_name in attr_names:
+            attr = getattr(self, attr_name)
+            if isinstance(attr, BaseDataModel):
+                result = attr._find_in_graph(
+                    key, _visited_nodes=_visited_nodes)
+                if result is not None:
+                    return result
+            elif isinstance(attr, (collections.InstrumentedList, list)):
+                for item in attr:
+                    if isinstance(item, BaseDataModel):
+                        result = item._find_in_graph(
+                            key, _visited_nodes=_visited_nodes)
+                        if result is not None:
+                            return result
         # If we are here we didn't find it.
         return None
 
@@ -321,11 +326,7 @@ class Pool(BaseDataModel):
                     break
         for pool in self.load_balancer.pools:
             if pool.id == self.id:
-                try:
-                    self.load_balancer.pools.remove(pool)
-                except ValueError:
-                    LOG.debug("Pool %s has already been removed from load "
-                              "balancer pools list.", pool.id)
+                self.load_balancer.pools.remove(pool)
                 break
         for l7policy in self.l7policies:
             if l7policy.redirect_pool_id == self.id:
@@ -385,7 +386,8 @@ class Listener(BaseDataModel):
                  timeout_client_data=None, timeout_member_connect=None,
                  timeout_member_data=None, timeout_tcp_inspect=None,
                  tags=None, client_ca_tls_certificate_id=None,
-                 client_authentication=None, client_crl_container_id=None):
+                 client_authentication=None, client_crl_container_id=None,
+                 allowed_cidrs=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -417,6 +419,7 @@ class Listener(BaseDataModel):
         self.client_ca_tls_certificate_id = client_ca_tls_certificate_id
         self.client_authentication = client_authentication
         self.client_crl_container_id = client_crl_container_id
+        self.allowed_cidrs = allowed_cidrs or []
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -776,3 +779,16 @@ class FlavorProfile(BaseDataModel):
         self.name = name
         self.provider_name = provider_name
         self.flavor_data = flavor_data
+
+
+class ListenerCidr(BaseDataModel):
+
+    def __init__(self, listener_id=None, cidr=None):
+        self.listener_id = listener_id
+        self.cidr = cidr
+
+    # SQLAlchemy kindly attaches the whole listener object so
+    # let's keep this simple by overriding the to_dict for this
+    # object. Otherwise we recurse down the "ghost" listener object.
+    def to_dict(self, **kwargs):
+        return {'cidr': self.cidr, 'listener_id': self.listener_id}
