@@ -121,6 +121,25 @@ class JinjaTemplater(object):
         JINJA_ENV.filters['hash_amp_id'] = octavia_utils.base64_sha1_string
         return JINJA_ENV.get_template(os.path.basename(self.haproxy_template))
 
+    def _format_log_string(self, load_balancer, protocol):
+        log_format = CONF.haproxy_amphora.user_log_format.replace(
+            '{project_id}', load_balancer.project_id)
+        log_format = log_format.replace('{lb_id}', load_balancer.id)
+
+        # Order of these filters matter.
+        # TODO(johnsom) Remove when HAProxy handles the format string
+        #               with HTTP variables in TCP listeners.
+        #               Currently it either throws an error or just fails
+        #               to log the message.
+        if protocol not in constants.HAPROXY_HTTP_PROTOCOLS:
+            log_format = log_format.replace('%{+Q}r', '-')
+            log_format = log_format.replace('%r', '-')
+            log_format = log_format.replace('%{+Q}ST', '-')
+            log_format = log_format.replace('%ST', '-')
+
+        log_format = log_format.replace(' ', '\\ ')
+        return log_format
+
     def render_loadbalancer_obj(self, host_amphora, listener, socket_path=None,
                                 feature_compatibility=None,
                                 client_ca_filename=None, client_crl=None,
@@ -145,6 +164,9 @@ class JinjaTemplater(object):
              'stats_sock': socket_path,
              'log_http': self.log_http,
              'log_server': self.log_server,
+             'administrative_log_facility':
+                 CONF.amphora_agent.administrative_log_facility,
+             'user_log_facility': CONF.amphora_agent.user_log_facility,
              'connection_logging': self.connection_logging},
             constants=constants)
 
@@ -226,6 +248,9 @@ class JinjaTemplater(object):
             'timeout_tcp_inspect': (listener.timeout_tcp_inspect or
                                     CONF.haproxy_amphora.timeout_tcp_inspect),
         }
+        if self.connection_logging:
+            ret_value['user_log_format'] = (
+                self._format_log_string(loadbalancer, listener.protocol))
         if listener.connection_limit and listener.connection_limit > -1:
             ret_value['connection_limit'] = listener.connection_limit
         else:
@@ -440,10 +465,10 @@ class JinjaTemplater(object):
 
             if not code:
                 continue
-            elif '-' in code:
+            if '-' in code:
                 low, hi = code.split('-')[:2]
                 retval.update(
                     str(i) for i in six.moves.xrange(int(low), int(hi) + 1))
             else:
                 retval.add(code)
-        return retval
+        return sorted(retval)
