@@ -95,8 +95,42 @@ class TestQuotas(base.BaseAPITest):
         response = self.get(self.QUOTAS_PATH)
         quota_list = response.json
 
-        quota1['project_id'] = project_id1
-        quota2['project_id'] = project_id2
+        quota1['project_id'] = quota1['tenant_id'] = project_id1
+        quota2['project_id'] = quota2['tenant_id'] = project_id2
+        # Expected deprecated names until T
+        quota1['healthmonitor'] = quota1['health_monitor']
+        quota1['loadbalancer'] = quota1['load_balancer']
+        quota2['healthmonitor'] = quota2['health_monitor']
+        quota2['loadbalancer'] = quota2['load_balancer']
+
+        expected = {'quotas': [quota1, quota2], 'quotas_links': []}
+        self.assertEqual(expected, quota_list)
+
+    def test_deprecated_get_and_put_vars(self):
+        project_id1 = uuidutils.generate_uuid()
+        project_id2 = uuidutils.generate_uuid()
+        quota_path1 = self.QUOTA_PATH.format(project_id=project_id1)
+        quota1 = {'load_balancer': constants.QUOTA_UNLIMITED, 'listener': 30,
+                  'pool': 30, 'health_monitor': 30, 'member': 30}
+        body1 = {'quota': quota1}
+        self.put(quota_path1, body1, status=202)
+        quota_path2 = self.QUOTA_PATH.format(project_id=project_id2)
+        quota2 = {'loadbalancer': 50, 'listener': 50, 'pool': 50,
+                  'healthmonitor': 50, 'member': 50}
+        body2 = {'quota': quota2}
+        self.put(quota_path2, body2, status=202)
+
+        response = self.get(self.QUOTAS_PATH)
+        quota_list = response.json
+
+        quota1['project_id'] = quota1['tenant_id'] = project_id1
+        quota2['project_id'] = quota2['tenant_id'] = project_id2
+        # Expected deprecated names until T
+        quota1['healthmonitor'] = quota1['health_monitor']
+        quota1['loadbalancer'] = quota1['load_balancer']
+        quota2['health_monitor'] = quota2['healthmonitor']
+        quota2['load_balancer'] = quota2['loadbalancer']
+
         expected = {'quotas': [quota1, quota2], 'quotas_links': []}
         self.assertEqual(expected, quota_list)
 
@@ -118,7 +152,7 @@ class TestQuotas(base.BaseAPITest):
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         with mock.patch.object(octavia.common.context.Context, 'project_id',
                                uuidutils.generate_uuid()):
-                response = self.get(self.QUOTAS_PATH, status=403)
+            response = self.get(self.QUOTAS_PATH, status=403)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(self.NOT_AUTHORIZED_BODY, response.json)
 
