@@ -12,7 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import os
+
+from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
+from oslo_db.sqlalchemy import session as db_session
 from oslo_db.sqlalchemy import test_base
 
 from octavia.common import config
@@ -24,29 +28,40 @@ from octavia.db import models
 
 class OctaviaDBTestBase(test_base.DbTestCase):
 
-    def setUp(self):
+    def setUp(self, connection_string='sqlite://'):
         super(OctaviaDBTestBase, self).setUp()
         # NOTE(blogan): doing this for now because using the engine and
         # session set up in the fixture for test_base.DbTestCase does not work
         # with the API functional tests.  Need to investigate more if this
         # becomes a problem
         conf = self.useFixture(oslo_fixture.Config(config.cfg.CONF))
-        conf.config(group="database", connection='sqlite://')
+        conf.config(group="database", connection=connection_string)
+
+        # We need to get our own Facade so that the file backed sqlite tests
+        # don't use the _FACADE singleton. Some tests will use in-memory
+        # sqlite, some will use a file backed sqlite.
+        if 'sqlite:///' in connection_string:
+            facade = db_session.EngineFacade.from_config(cfg.CONF,
+                                                         sqlite_fk=True)
+            engine = facade.get_engine()
+            self.session = facade.get_session(expire_on_commit=True,
+                                              autocommit=True)
+        else:
+            engine = db_api.get_engine()
+            self.session = db_api.get_session()
 
-        # needed for closure
-        engine = db_api.get_engine()
-        session = db_api.get_session()
         base_models.BASE.metadata.create_all(engine)
-        self._seed_lookup_tables(session)
+        self._seed_lookup_tables(self.session)
 
         def clear_tables():
             """Unregister all data models."""
             base_models.BASE.metadata.drop_all(engine)
+            # If we created a file, clean it up too
+            if 'sqlite:///' in connection_string:
+                os.remove(connection_string.replace('sqlite:///', ''))
 
         self.addCleanup(clear_tables)
 
-        self.session = session
-
     def _seed_lookup_tables(self, session):
         self._seed_lookup_table(
             session, constants.SUPPORTED_PROVISIONING_STATUSES,
