@@ -41,14 +41,15 @@ class HAProxyCompatTestCase(base.TestCase):
             "    option splice-response\n"
             "    option http-keep-alive\n\n\n\n"
             "frontend sample_listener_id_1\n"
-            "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-            "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-            "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc\n"
             "    maxconn {maxconn}\n"
             "    bind 10.0.0.2:80\n"
             "    mode http\n"
             "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-            "    timeout client 50000\n\n").format(
+            "    timeout client 50000\n"
+            "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+            "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+            "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+            "%tsc\n\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         self.backend_without_external = (
             "backend sample_pool_id_1:sample_listener_id_1\n"
