@@ -16,11 +16,16 @@
 import copy
 import os
 
+from oslo_config import cfg
+from oslo_config import fixture as oslo_fixture
+
 from octavia.common import constants
 from octavia.common.jinja.haproxy.combined_listeners import jinja_cfg
 from octavia.tests.unit import base
 from octavia.tests.unit.common.sample_configs import sample_configs_combined
 
+CONF = cfg.CONF
+
 
 class TestHaproxyCfg(base.TestCase):
     def setUp(self):
@@ -34,24 +39,24 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual('haproxy.cfg.j2', template.name)
 
     def test_render_template_tls(self):
+        conf = oslo_fixture.Config(cfg.CONF)
+        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
+        FAKE_CRT_LIST_FILENAME = os.path.join(
+            CONF.haproxy_amphora.base_cert_dir,
+            'sample_loadbalancer_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
-              "ssl crt /var/lib/octavia/certs/"
-              "sample_loadbalancer_id_1/tls_container_id.pem "
-              "crt /var/lib/octavia/certs/sample_loadbalancer_id_1 "
+              "ssl crt-list {crt_list} "
               "ca-file /var/lib/octavia/certs/sample_loadbalancer_id_1/"
               "client_ca.pem verify required crl-file /var/lib/octavia/"
               "certs/sample_loadbalancer_id_1/SHA_ID.pem\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+              "    timeout client 50000\n").format(
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -70,38 +75,32 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2 cookie "
               "sample_member_id_2\n\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
-        tls_tupe = {'cont_id_1':
-                    sample_configs_combined.sample_tls_container_tuple(
-                        id='tls_container_id',
-                        certificate='imaCert1', private_key='imaPrivateKey1',
-                        primary_cn='FakeCN')}
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
                 proto='TERMINATED_HTTPS', tls=True, sni=True,
                 client_ca_cert=True, client_crl_cert=True)],
-            tls_tupe, client_ca_filename='client_ca.pem',
-            client_crl='SHA_ID.pem')
+            client_ca_filename='client_ca.pem', client_crl='SHA_ID.pem')
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(
                 frontend=fe, backend=be),
             rendered_obj)
 
     def test_render_template_tls_no_sni(self):
+        conf = oslo_fixture.Config(cfg.CONF)
+        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
+        FAKE_CRT_LIST_FILENAME = os.path.join(
+            CONF.haproxy_amphora.base_cert_dir,
+            'sample_loadbalancer_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
-              "    bind 10.0.0.2:443 "
-              "ssl crt /var/lib/octavia/certs/"
-              "sample_loadbalancer_id_1/tls_container_id.pem\n"
+              "    bind 10.0.0.2:443 ssl crt-list {crt_list}\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+              "    timeout client 50000\n").format(
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -123,13 +122,7 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
-                proto='TERMINATED_HTTPS', tls=True)],
-            tls_certs={'cont_id_1':
-                       sample_configs_combined.sample_tls_container_tuple(
-                           id='tls_container_id',
-                           certificate='ImAalsdkfjCert',
-                           private_key='ImAsdlfksdjPrivateKey',
-                           primary_cn="FakeCN")})
+                proto='TERMINATED_HTTPS', tls=True)])
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(
                 frontend=fe, backend=be),
@@ -192,15 +185,11 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_custom_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 2\n\n").format(
+              "    timeout client 2\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
@@ -231,15 +220,11 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_null_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
@@ -299,16 +284,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_https_real_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -331,20 +316,20 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(proto='HTTPS')])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_https_hello_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -367,7 +352,7 @@ class TestHaproxyCfg(base.TestCase):
             [sample_configs_combined.sample_listener_tuple(
                 proto='HTTPS', monitor_proto='TLS-HELLO')])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_no_monitor_http(self):
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
@@ -441,16 +426,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_monitor_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -469,7 +454,7 @@ class TestHaproxyCfg(base.TestCase):
             [sample_configs_combined.sample_listener_tuple(proto='HTTPS',
                                                            monitor=False)])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_health_monitor_http_check(self):
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
@@ -500,16 +485,16 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_persistence_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -525,7 +510,7 @@ class TestHaproxyCfg(base.TestCase):
             [sample_configs_combined.sample_listener_tuple(
                 proto='HTTPS', monitor=False, persistence=False)])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_no_persistence_http(self):
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
@@ -604,18 +589,18 @@ class TestHaproxyCfg(base.TestCase):
         sample_listener = sample_configs_combined.sample_listener_tuple(
             proto='HTTPS', monitor=False)
         fe = ("frontend {listener_id}\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend {pool_id}:{listener_id}\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN,
             pool_id=sample_listener.default_pool.id,
             listener_id=sample_listener.id)
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend {pool_id}:{listener_id}\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -635,19 +620,19 @@ class TestHaproxyCfg(base.TestCase):
             sample_amphora,
             [sample_listener])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be), rendered_obj)
+            frontend=fe, logging=lg, backend=be), rendered_obj)
 
     def test_render_template_limited_connections(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn 2014\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n")
+              "    timeout client 50000\n")
+        lg = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode tcp\n"
               "    balance roundrobin\n"
@@ -666,14 +651,11 @@ class TestHaproxyCfg(base.TestCase):
             [sample_configs_combined.sample_listener_tuple(
                 proto='HTTPS', monitor=False, connection_limit=2014)])
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
-            frontend=fe, backend=be, global_opts=g_opts), rendered_obj)
+            frontend=fe, logging=lg, backend=be, global_opts=g_opts),
+            rendered_obj)
 
     def test_render_template_l7policies(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
@@ -698,7 +680,7 @@ class TestHaproxyCfg(base.TestCase):
               "    redirect code 302 prefix https://example.com if "
               "!sample_l7rule_id_2 sample_l7rule_id_3\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n").format(
+              "    timeout client 50000\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
@@ -941,13 +923,13 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_transform_listener(self):
         in_listener = sample_configs_combined.sample_listener_tuple()
-        ret = self.jinja_cfg._transform_listener(in_listener, None, {},
+        ret = self.jinja_cfg._transform_listener(in_listener, {},
                                                  in_listener.load_balancer)
         self.assertEqual(sample_configs_combined.RET_LISTENER, ret)
 
     def test_transform_listener_with_l7(self):
         in_listener = sample_configs_combined.sample_listener_tuple(l7=True)
-        ret = self.jinja_cfg._transform_listener(in_listener, None, {},
+        ret = self.jinja_cfg._transform_listener(in_listener, {},
                                                  in_listener.load_balancer)
         self.assertEqual(sample_configs_combined.RET_LISTENER_L7, ret)
 
@@ -955,7 +937,7 @@ class TestHaproxyCfg(base.TestCase):
         in_amphora = sample_configs_combined.sample_amphora_tuple()
         in_listener = sample_configs_combined.sample_listener_tuple()
         ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listener.load_balancer, [in_listener], None, {})
+            in_amphora, in_listener.load_balancer, [in_listener], {})
         self.assertEqual(sample_configs_combined.RET_LB, ret)
 
     def test_transform_amphora(self):
@@ -967,7 +949,7 @@ class TestHaproxyCfg(base.TestCase):
         in_amphora = sample_configs_combined.sample_amphora_tuple()
         in_listener = sample_configs_combined.sample_listener_tuple(l7=True)
         ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listener.load_balancer, [in_listener], None, {})
+            in_amphora, in_listener.load_balancer, [in_listener], {})
         self.assertEqual(sample_configs_combined.RET_LB_L7, ret)
 
     def test_transform_l7policy(self):
@@ -1051,7 +1033,7 @@ class TestHaproxyCfg(base.TestCase):
         )
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(
-                defaults=defaults),
+                defaults=defaults, logging="\n"),
             rendered_obj)
 
     def test_http_reuse(self):
@@ -1085,7 +1067,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_amphora,
             [sample_proxy_listener],
-            tls_certs=None,
             haproxy_versions=("1", "8", "1"))
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(backend=be),
@@ -1113,7 +1094,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_amphora,
             [sample_proxy_listener],
-            tls_certs=None,
             haproxy_versions=("1", "5", "18"))
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(backend=be),
@@ -1124,10 +1104,6 @@ class TestHaproxyCfg(base.TestCase):
             base_amp_path='/var/lib/octavia',
             base_crt_dir='/var/lib/octavia/certs')
         fe = ("frontend sample_listener_id_1\n"
-              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
-              "%ci\\ %cp\\ %t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ "
-              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
-              "%tsc\n"
               "    maxconn 1000000\n"
               "    redirect scheme https if !{ ssl_fc }\n"
               "    bind 10.0.0.2:443\n"
@@ -1164,7 +1140,7 @@ class TestHaproxyCfg(base.TestCase):
               "if sample_l7rule_id_7 !sample_l7rule_id_8 !sample_l7rule_id_9 "
               "!sample_l7rule_id_10 sample_l7rule_id_11\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
-              "    timeout client 50000\n\n")
+              "    timeout client 50000\n")
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -1199,7 +1175,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_listener],
-            tls_certs=None,
             haproxy_versions=("1", "5", "18"))
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(
