@@ -96,17 +96,23 @@ class TestNovaClient(base.TestCase):
         conf.config(group="controller_worker",
                     amp_boot_network_list=['1', '2'])
         self.conf = conf
+        self.fake_image_uuid = uuidutils.generate_uuid()
 
         self.amphora = models.Amphora(
             compute_id=uuidutils.generate_uuid(),
             status='ACTIVE',
-            lb_network_ip='10.0.0.1'
+            lb_network_ip='10.0.0.1',
+            image_id=self.fake_image_uuid,
+            compute_flavor=uuidutils.generate_uuid()
         )
 
         self.nova_response = mock.Mock()
         self.nova_response.id = self.amphora.compute_id
         self.nova_response.status = 'ACTIVE'
         self.nova_response.fault = 'FAKE_FAULT'
+        setattr(self.nova_response, 'OS-EXT-AZ:availability_zone', None)
+        self.nova_response.image = {'id': self.amphora.image_id}
+        self.nova_response.flavor = {'id': self.amphora.compute_flavor}
 
         self.interface_list = mock.MagicMock()
         self.interface_list.net_id = '1'
@@ -121,6 +127,8 @@ class TestNovaClient(base.TestCase):
         self.manager.manager = mock.MagicMock()
         self.manager.server_groups = mock.MagicMock()
         self.manager._nova_client = mock.MagicMock()
+        self.manager.flavor_manager = mock.MagicMock()
+        self.manager.flavor_manager.get = mock.MagicMock()
 
         self.nova_response.interface_list.side_effect = [[self.interface_list]]
         self.manager.manager.get.return_value = self.nova_response
@@ -141,6 +149,14 @@ class TestNovaClient(base.TestCase):
         self.server_group_mock.policy = self.server_group_policy
         self.server_group_mock.id = self.server_group_id
 
+        self.volume_mock = mock.MagicMock()
+        setattr(self.volume_mock, 'volumeId', '1')
+
+        self.port_id = uuidutils.generate_uuid()
+        self.compute_id = uuidutils.generate_uuid()
+        self.network_id = uuidutils.generate_uuid()
+        self.flavor_id = uuidutils.generate_uuid()
+
         super(TestNovaClient, self).setUp()
 
     def test_build(self):
@@ -165,7 +181,39 @@ class TestNovaClient(base.TestCase):
             userdata='Blah',
             config_drive=True,
             scheduler_hints=None,
-            availability_zone=None
+            availability_zone=None,
+            block_device_mapping={}
+        )
+
+    @mock.patch('stevedore.driver.DriverManager.driver')
+    def test_build_with_cinder_volume(self, mock_driver):
+        self.conf.config(group="controller_worker",
+                         volume_driver='volume_cinder_driver')
+        self.manager.volume_driver = mock_driver
+        mock_driver.create_volume_from_image.return_value = 1
+        amphora_id = self.manager.build(amphora_flavor=1, image_id=1,
+                                        key_name=1,
+                                        sec_groups=1,
+                                        network_ids=[1],
+                                        port_ids=[2],
+                                        user_data='Blah',
+                                        config_drive_files='Files Blah')
+
+        self.assertEqual(self.amphora.compute_id, amphora_id)
+        mock_driver.create_volume_from_image.assert_called_with(1)
+        self.manager.manager.create.assert_called_with(
+            name="amphora_name",
+            nics=[{'net-id': 1}, {'port-id': 2}],
+            image=None,
+            flavor=1,
+            key_name=1,
+            security_groups=1,
+            files='Files Blah',
+            userdata='Blah',
+            config_drive=True,
+            scheduler_hints=None,
+            availability_zone=None,
+            block_device_mapping={'vda': '1:::true'}
         )
 
     def test_build_with_availability_zone(self):
@@ -193,7 +241,8 @@ class TestNovaClient(base.TestCase):
             userdata='Blah',
             config_drive=True,
             scheduler_hints=None,
-            availability_zone=FAKE_AZ
+            availability_zone=FAKE_AZ,
+            block_device_mapping={}
         )
 
     def test_build_with_random_amphora_name_length(self):
@@ -229,7 +278,8 @@ class TestNovaClient(base.TestCase):
             userdata='Blah',
             config_drive=True,
             scheduler_hints=None,
-            availability_zone=None
+            availability_zone=None,
+            block_device_mapping={}
         )
 
     def test_bad_build(self):
@@ -286,6 +336,13 @@ class TestNovaClient(base.TestCase):
         self.assertEqual(self.nova_response.fault, fault)
         self.nova_response.interface_list.called_with()
 
+    def test_translate_amphora_no_availability_zone(self):
+        delattr(self.nova_response, 'OS-EXT-AZ:availability_zone')
+        amphora, fault = self.manager._translate_amphora(self.nova_response)
+        self.assertEqual(self.amphora, amphora)
+        self.assertEqual(self.nova_response.fault, fault)
+        self.nova_response.interface_list.called_with()
+
     def test_bad_translate_amphora(self):
         self.nova_response.interface_list.side_effect = Exception
         self.manager._nova_client.networks.get.side_effect = Exception
@@ -293,6 +350,22 @@ class TestNovaClient(base.TestCase):
         self.assertIsNone(amphora.lb_network_ip)
         self.nova_response.interface_list.called_with()
 
+    @mock.patch('stevedore.driver.DriverManager.driver')
+    def test_translate_amphora_use_cinder(self, mock_driver):
+        self.conf.config(group="controller_worker",
+                         volume_driver='volume_cinder_driver')
+        volumes_manager = self.manager._nova_client.volumes
+        volumes_manager.get_server_volumes.return_value = [self.volume_mock]
+        self.manager.volume_driver = mock_driver
+        mock_driver.get_image_from_volume.return_value = self.fake_image_uuid
+        amphora, fault = self.manager._translate_amphora(self.nova_response)
+        self.assertEqual(self.amphora, amphora)
+        self.assertEqual(self.nova_response.fault, fault)
+        self.nova_response.interface_list.called_with()
+        volumes_manager.get_server_volumes.assert_called_with(
+            self.nova_response.id)
+        mock_driver.get_image_from_volume.assert_called_with('1')
+
     def test_create_server_group(self):
         self.manager.server_groups.create.return_value = self.server_group_mock
 
@@ -332,3 +405,42 @@ class TestNovaClient(base.TestCase):
                           self.manager.delete_server_group,
                           self.server_group_id)
         self.manager.server_groups.delete.called_with(self.server_group_id)
+
+    def test_attach_network_or_port(self):
+        self.manager.attach_network_or_port(self.compute_id,
+                                            self.network_id)
+        self.manager.manager.interface_attach.assert_called_with(
+            server=self.compute_id, net_id=self.network_id, fixed_ip=None,
+            port_id=None)
+
+    def test_attach_network_or_port_exception(self):
+        self.manager.manager.interface_attach.side_effect = [
+            nova_exceptions.NotFound('test_exception')]
+        self.assertRaises(nova_exceptions.NotFound,
+                          self.manager.attach_network_or_port,
+                          self.compute_id, self.network_id)
+
+    def test_detach_network(self):
+        self.manager.detach_port(self.compute_id,
+                                 self.port_id)
+        self.manager.manager.interface_detach.assert_called_with(
+            server=self.compute_id, port_id=self.port_id)
+
+    def test_detach_network_with_exception(self):
+        self.manager.manager.interface_detach.side_effect = [Exception]
+        self.manager.detach_port(self.compute_id,
+                                 self.port_id)
+
+    def test_validate_flavor(self):
+        self.manager.validate_flavor(self.flavor_id)
+        self.manager.flavor_manager.get.assert_called_with(self.flavor_id)
+
+    def test_validate_flavor_with_exception(self):
+        self.manager.flavor_manager.get.side_effect = [
+            nova_exceptions.NotFound(404), exceptions.OctaviaException]
+        self.assertRaises(exceptions.InvalidSubresource,
+                          self.manager.validate_flavor,
+                          "bogus")
+        self.assertRaises(exceptions.OctaviaException,
+                          self.manager.validate_flavor,
+                          "bogus")
